@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2021 IRCAD France
+ * Copyright (C) 2020-2024 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,9 +22,9 @@
 
 #pragma once
 
-#include "viz/qt3d/config.hpp"
+#include <sight/viz/qt3d/config.hpp>
 
-#include <core/FactoryRegistry.hpp>
+#include <core/factory_registry.hpp>
 #include <core/macros.hpp>
 
 #include <string>
@@ -32,16 +32,15 @@
 namespace sight::viz::qt3d
 {
 
-class IWindowInteractor;
+class window_interactor;
 
 namespace registry
 {
 
-typedef std::string KeyType;
+using key_t = std::string;
+using type  = sight::core::factory_registry<std::shared_ptr<sight::viz::qt3d::window_interactor>(), key_t>;
 
-typedef sight::core::FactoryRegistry<SPTR(sight::viz::qt3d::IWindowInteractor)(), KeyType> Type;
-
-VIZ_QT3D_API SPTR(Type) get();
+SIGHT_VIZ_QT3D_API SPTR(type) get();
 
 } // namespace registry.
 
